@@ -18,13 +18,11 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-     $Id: discid.h 9569 2007-10-26 22:04:08Z robert $
-
 --------------------------------------------------------------------------- */
 #ifndef MUSICBRAINZ_DISC_ID_H
 #define MUSICBRAINZ_DISC_ID_H
 
-#ifdef WIN32
+#if (defined(_WIN32) || defined(_WIN64))
 #	ifdef libdiscid_EXPORTS
 #		define LIBDISCID_API __declspec(dllexport)
 #	else
@@ -79,7 +77,9 @@
  * \section Contact
  *
  *  - <a href="http://lists.musicbrainz.org/mailman/listinfo/musicbrainz-devel">MusicBrainz Development Mailing List</a>
- *  - <a href="http://bugs.musicbrainz.org/query?component=libdiscid">MusicBrainz Bug Tracker</a>
+ *  - <a href="http://tickets.musicbrainz.org/browse/LIB">MusicBrainz Bug Tracker</a>
+ *  - <a href="http://musicbrainz.org/doc/libdiscid">MusicBrainz Documentation</a>
+ *  - <a href="https://github.com/metabrainz/libdiscid">Github Repository</a>
  *
  */ 
 
@@ -277,6 +277,26 @@ LIBDISCID_API int discid_get_track_offset(DiscId *d, int track_num);
  */
 LIBDISCID_API int discid_get_track_length(DiscId *d, int track_num);
 
+/**
+ * Return the Media Catalogue Number for the disc.
+ *
+ * @param d a DiscId object created by discid_new()
+ * @return a string containing an Media Catalogue Number of the disk
+ */
+LIBDISCID_API char* discid_get_mcn(DiscId *d);
+
+/**
+ * Return the ISRC for a track.
+ *
+ * Only track numbers between (and including) discid_get_first_track_num()
+ * and discid_get_last_track_num() may be used.
+ *
+ * @param d a DiscId object created by discid_new()
+ * @param track_num the number of a track
+ * @return a string containing an ISRC for the specified track
+ */
+LIBDISCID_API char* discid_get_track_isrc(DiscId *d, int track_num);
+
 
 #ifdef __cplusplus
   }
